@@ -531,6 +531,8 @@ void yon_on_text_insert_only_digits(GtkEditable *editable, const gchar *text, gi
 
 void yon_gtk_entry_block_restricted_symbols(GtkEntry *target);
 
+void yon_gtk_entry_allow_password_symbols(GtkEntry *target);
+
 void yon_gtk_entry_block_languages(GtkEntry *target);
 
 void yon_gtk_entry_block_symbols(GtkEntry *target, char *symbols);
@@ -608,4 +610,7 @@ void yon_combo_box_set_default(GtkComboBoxText *target, char *command, char*(res
 int yon_ip_mask_get_bits(char *mask);
 int yon_ip_check(char *ip);
 
+void yon_gtk_widget_register_parameter(GtkWidget *target, char *config_parameter, char *get_command, char *object_property);
+void yon_gtk_widget_register_parameter_manual(GtkWidget *target, char *config_parameter, char *get_command, char *object_property);
+void yon_gtk_widget_register_parameter_activate();
 #endif
\ No newline at end of file
